"""
The API allows convert textual content to audio format in the following formats:
"""
mono_8khz_8bit = "8khz_8bit_mono"
"""8 kHz, 8 Bit, Mono"""

stereo_8khz_8bit = "8khz_8bit_stereo"
"""8 kHz, 8 Bit, Stereo"""

mono_8khz_16bit = "8khz_16bit_mono"
"""8 kHz, 16 Bit, Mono"""

stereo_8khz_16bit = "8khz_16bit_stereo"
"""8 kHz, 16 Bit, Stereo"""

mono_11khz_8bit = "11khz_8bit_mono"
"""11 kHz, 8 Bit, Mono"""

stereo_11khz_8bit = "11khz_8bit_stereo"
"""11 kHz, 8 Bit, Stereo"""

mono_11khz_16bit = "11khz_16bit_mono"
"""11 kHz, 16 Bit, Mono"""

stereo_11khz_16bit = "11khz_16bit_stereo"
"""11 kHz, 16 Bit, Stereo"""

mono_12khz_8bit = "12khz_8bit_mono"
"""12 kHz, 8 Bit, Mono"""

stereo_12khz_8bit = "12khz_8bit_stereo"
"""12 kHz, 8 Bit, Stereo"""

mono_12khz_16bit = "12khz_16bit_mono"
"""12 kHz, 16 Bit, Mono"""

stereo_12khz_16bit = "12khz_16bit_stereo"
"""12 kHz, 16 Bit, Stereo"""

mono_16khz_8bit = "16khz_8bit_mono"
"""16 kHz, 8 Bit, Mono"""

stereo_16khz_8bit = "16khz_8bit_stereo"
"""16 kHz, 8 Bit, Stereo"""

mono_16khz_16bit = "16khz_16bit_mono"
"""16 kHz, 16 Bit, Mono"""

stereo_16khz_16bit = "16khz_16bit_stereo"
"""16 kHz, 16 Bit, Stereo"""

mono_22khz_8bit = "22khz_8bit_mono"
"""22 kHz, 8 Bit, Mono"""

stereo_22khz_8bit = "22khz_8bit_stereo"
"""22 kHz, 8 Bit, Stereo"""

mono_22khz_16bit = "22khz_16bit_mono"
"""22 kHz, 16 Bit, Mono"""

stereo_22khz_16bit = "22khz_16bit_stereo"
"""22 kHz, 16 Bit, Stereo"""

mono_24khz_8bit = "24khz_8bit_mono"
"""24 kHz, 8 Bit, Mono"""

stereo_24khz_8bit = "24khz_8bit_stereo"
"""24 kHz, 8 Bit, Stereo"""

mono_24khz_16bit = "24khz_16bit_mono"
"""24 kHz, 16 Bit, Mono"""

stereo_24khz_16bit = "24khz_16bit_stereo"
"""24 kHz, 16 Bit, Stereo"""

mono_32khz_8bit = "32khz_8bit_mono"
"""32 kHz, 8 Bit, Mono"""

stereo_32khz_8bit = "32khz_8bit_stereo"
"""32 kHz, 8 Bit, Stereo"""

mono_32khz_16bit = "32khz_16bit_mono"
"""32 kHz, 16 Bit, Mono"""

stereo_32khz_16bit = "32khz_16bit_stereo"
"""32 kHz, 16 Bit, Stereo"""

mono_44khz_8bit = "44khz_8bit_mono"
"""44 kHz, 8 Bit, Mono"""

stereo_44khz_8bit = "44khz_8bit_stereo"
"""44 kHz, 8 Bit, Stereo"""

mono_44khz_16bit = "44khz_16bit_mono"
"""44 kHz, 16 Bit, Mono"""

stereo_44khz_16bit = "44khz_16bit_stereo"
"""44 kHz, 16 Bit, Stereo"""

mono_48khz_8bit = "48khz_8bit_mono"
"""48 kHz, 8 Bit, Mono"""

stereo_48khz_8bit = "48khz_8bit_stereo"
"""48 kHz, 8 Bit, Stereo"""

mono_48khz_16bit = "48khz_16bit_mono"
"""48 kHz, 16 Bit, Mono"""

stereo_48khz_16bit = "48khz_16bit_stereo"
"""48 kHz, 16 Bit, Stereo"""

mono_alaw_8khz = "alaw_8khz_mono"
"""ALaw, 8 kHz, Mono"""

stereo_alaw_8khz = "alaw_8khz_stereo"
"""ALaw, 8 kHz, Stereo"""

mono_alaw_11khz = "alaw_11khz_mono"
"""ALaw, 11 kHz, Mono"""

stereo_alaw_11khz = "alaw_11khz_stereo"
"""ALaw, 11 kHz, Stereo"""

mono_alaw_22khz = "alaw_22khz_mono"
"""ALaw, 22 kHz, Mono"""

stereo_alaw_22khz = "alaw_22khz_stereo"
"""ALaw, 22 kHz, Stereo"""

mono_alaw_44khz = "alaw_44khz_mono"
"""ALaw, 44 kHz, Mono"""

stereo_alaw_44khz = "alaw_44khz_stereo"
"""ALaw, 44 kHz, Stereo"""

mono_ulaw_8khz = "ulaw_8khz_mono"
"""uLaw, 8 kHz, Mono"""

stereo_ulaw_8khz = "ulaw_8khz_stereo"
"""uLaw, 8 kHz, Stereo"""

mono_ulaw_11khz = "ulaw_11khz_mono"
"""uLaw, 11 kHz, Mono"""

stereo_ulaw_11khz = "ulaw_11khz_stereo"
"""uLaw, 11 kHz, Stereo"""

mono_ulaw_22khz = "ulaw_22khz_mono"
"""uLaw, 22 kHz, Mono"""

stereo_ulaw_22khz = "ulaw_22khz_stereo"
"""uLaw, 22 kHz, Stereo"""

mono_ulaw_44khz = "ulaw_44khz_mono"
"""uLaw, 44 kHz, Mono"""

stereo_ulaw_44khz = "ulaw_44khz_stereo"
"""uLaw, 44 kHz, Stereo"""
