class ar_eg:
    """Arabic (Egypt)"""

    Oda = "Oda"
    """Female. Default voice for this language."""


class ar_sa:
    """Arabic (Saudi Arabia)"""

    Salim = "Salim"
    """Male. Default voice for this language."""


class bg_bg:
    """Bulgarian"""

    Dimo = "Dimo"
    """Male. Default voice for this language."""


class ca_es:
    """Catalan"""

    Rut = "Rut"
    """Female. Default voice for this language."""


class zh_cn:
    """Chinese (China)"""

    Luli = "Luli"
    """Female. Default voice for this language."""

    Shu = "Shu"
    """Female."""

    Chow = "Chow"
    """Female."""

    Wang = "Wang"
    """Male."""


class zh_hk:
    """Chinese (Hong Kong)"""

    Jia = "Jia"
    """Female. Default voice for this language."""

    Xia = "Xia"
    """Female."""

    Chen = "Chen"
    """Male."""


class zh_tw:
    """Chinese (Taiwan)"""

    Akemi = "Akemi"
    """Female. Default voice for this language."""

    Lin = "Lin"
    """Female."""

    Lee = "Lee"
    """Male."""


class hr_hr:
    """Croatian"""

    Nikola = "Nikola"
    """Male. Default voice for this language."""


class cs_cz:
    """Czech"""

    Josef = "Josef"
    """Male. Default voice for this language."""


class da_dk:
    """Danish"""

    Freja = "Freja"
    """Female. Default voice for this language."""


class nl_be:
    """Dutch (Belgium)"""

    Daan = "Daan"
    """Male. Default voice for this language."""


class nl_nl:
    """Dutch (Netherlands)"""

    Lotte = "Lotte"
    """Female. Default voice for this language."""

    Bram = "Bram"
    """Male."""


class en_au:
    """English (Australia)"""

    Zoe = "Zoe"
    """Female. Default voice for this language."""

    Isla = "Isla"
    """Female."""

    Evie = "Evie"
    """Female."""

    Jack = "Jack"
    """Male."""


class en_ca:
    """English (Canada)"""

    Rose = "Rose"
    """Female. Default voice for this language."""

    Clara = "Clara"
    """Female."""

    Emma = "Emma"
    """Female."""

    Mason = "Mason"
    """Male."""


class en_gb:
    """English (Great Britain)"""

    Alice = "Alice"
    """Female. Default voice for this language."""

    Nancy = "Nancy"
    """Female."""

    Lily = "Lily"
    """Female."""

    Harry = "Harry"
    """Male."""


class en_in:
    """English (India)"""

    Eka = "Eka"
    """Female. Default voice for this language."""

    Jai = "Jai"
    """Female."""

    Ajit = "Ajit"
    """Male."""


class en_ie:
    """English (Ireland)"""

    Oran = "Oran"
    """Male. Default voice for this language."""


class en_us:
    """English (United States)"""

    Linda = "Linda"
    """Female. Default voice for this language."""

    Amy = "Amy"
    """Female."""

    Mary = "Mary"
    """Female."""

    John = "John"
    """Male."""

    Mike = "Mike"
    """Male."""


class fi_fi:
    """Finnish"""

    Aada = "Aada"
    """Female. Default voice for this language."""


class fr_ca:
    """French (Canada)"""

    Emile = "Emile"
    """Female. Default voice for this language."""

    Olivia = "Olivia"
    """Female."""

    Logan = "Logan"
    """Female."""

    Felix = "Felix"
    """Male."""


class fr_fr:
    """French (France)"""

    Bette = "Bette"
    """Female. Default voice for this language."""

    Iva = "Iva"
    """Female."""

    Zola = "Zola"
    """Female."""

    Axel = "Axel"
    """Male."""


class fr_ch:
    """French (Switzerland)"""

    Theo = "Theo"
    """Male. Default voice for this language."""


class de_at:
    """German (Austria)"""

    Lukas = "Lukas"
    """Male. Default voice for this language."""


class de_de:
    """German (Germany)"""

    Hanna = "Hanna"
    """Female. Default voice for this language."""

    Lina = "Lina"
    """Female."""

    Jonas = "Jonas"
    """Male."""


class de_ch:
    """German (Switzerland)"""

    Tim = "Tim"
    """Male. Default voice for this language."""


class el_gr:
    """Greek"""

    Neo = "Neo"
    """Male. Default voice for this language."""


class he_il:
    """Hebrew"""

    Rami = "Rami"
    """Male. Default voice for this language."""


class hi_in:
    """Hindi"""

    Puja = "Puja"
    """Female. Default voice for this language."""

    Kabir = "Kabir"
    """Male."""


class hu_hu:
    """Hungarian"""

    Mate = "Mate"
    """Male. Default voice for this language."""


class id_id:
    """Indonesian"""

    Intan = "Intan"
    """Male. Default voice for this language."""


class it_it:
    """Italian"""

    Bria = "Bria"
    """Female. Default voice for this language."""

    Mia = "Mia"
    """Female."""

    Pietro = "Pietro"
    """Male."""


class ja_jp:
    """Japanese"""

    Hina = "Hina"
    """Female. Default voice for this language."""

    Airi = "Airi"
    """Female."""

    Fumi = "Fumi"
    """Female."""

    Akira = "Akira"
    """Male."""


class ko_kr:
    """Korean"""

    Nari = "Nari"
    """Female. Default voice for this language."""


class ms_my:
    """Malay"""

    Aqil = "Aqil"
    """Male. Default voice for this language."""


class nb_no:
    """Norwegian"""

    Marte = "Marte"
    """Female. Default voice for this language."""

    Erik = "Erik"
    """Male."""


class pl_pl:
    """Polish"""

    Julia = "Julia"
    """Female. Default voice for this language."""

    Jan = "Jan"
    """Male."""


class pt_br:
    """Portuguese (Brazil)"""

    Marcia = "Marcia"
    """Female. Default voice for this language."""

    Ligia = "Ligia"
    """Female."""

    Yara = "Yara"
    """Female."""

    Dinis = "Dinis"
    """Male."""


class pt_pt:
    """Portuguese (Portugal)"""

    Leonor = "Leonor"
    """Female. Default voice for this language."""


class ro_ro:
    """Romanian"""

    Doru = "Doru"
    """Male. Default voice for this language."""


class ru_ru:
    """Russian"""

    Olga = "Olga"
    """Female. Default voice for this language."""

    Marina = "Marina"
    """Female."""

    Peter = "Peter"
    """Male."""


class sk_sk:
    """Slovak"""

    Beda = "Beda"
    """Male. Default voice for this language."""


class sl_si:
    """Slovenian"""

    Vid = "Vid"
    """Male. Default voice for this language."""


class es_mx:
    """Spanish (Mexico)"""

    Juana = "Juana"
    """Female. Default voice for this language."""

    Silvia = "Silvia"
    """Female."""

    Teresa = "Teresa"
    """Female."""

    Jose = "Jose"
    """Male."""


class es_es:
    """Spanish (Spain)"""

    Camila = "Camila"
    """Female. Default voice for this language."""

    Sofia = "Sofia"
    """Female."""

    Luna = "Luna"
    """Female."""

    Diego = "Diego"
    """Male."""


class sv_se:
    """Swedish"""

    Molly = "Molly"
    """Female. Default voice for this language."""

    Hugo = "Hugo"
    """Male."""


class ta_in:
    """Tamil"""

    Sai = "Sai"
    """Male. Default voice for this language."""


class th_th:
    """Thai"""

    Ukrit = "Ukrit"
    """Male. Default voice for this language."""


class tr_tr:
    """Turkish"""

    Omer = "Omer"
    """Male. Default voice for this language."""


class vi_vn:
    """Vietnamese"""

    Chi = "Chi"
    """Male. Default voice for this language."""
