ar_eg = "ar-eg"
"""Arabic (Egypt)"""

ar_sa = "ar-sa"
"""Arabic (Saudi Arabia)"""

bg_bg = "bg-bg"
"""Bulgarian"""

ca_es = "ca-es"
"""Catalan"""

zh_cn = "zh-cn"
"""Chinese (China)"""

zh_hk = "zh-hk"
"""Chinese (Hong Kong)"""

zh_tw = "zh-tw"
"""Chinese (Taiwan)"""

hr_hr = "hr-hr"
"""Croatian"""

cs_cz = "cs-cz"
"""Czech"""

da_dk = "da-dk"
"""Danish"""

nl_be = "nl-be"
"""Dutch (Belgium)"""

nl_nl = "nl-nl"
"""Dutch (Netherlands)"""

en_au = "en-au"
"""English (Australia)"""

en_ca = "en-ca"
"""English (Canada)"""

en_gb = "en-gb"
"""English (Great Britain)"""

en_in = "en-in"
"""English (India)"""

en_ie = "en-ie"
"""English (Ireland)"""

en_us = "en-us"
"""English (United States)"""

fi_fi = "fi-fi"
"""Finnish"""

fr_ca = "fr-ca"
"""French (Canada)"""

fr_fr = "fr-fr"
"""French (France)"""

fr_ch = "fr-ch"
"""French (Switzerland)"""

de_at = "de-at"
"""German (Austria)"""

de_de = "de-de"
"""German (Germany)"""

de_ch = "de-ch"
"""German (Switzerland)"""

el_gr = "el-gr"
"""Greek"""

he_il = "he-il"
"""Hebrew"""

hi_in = "hi-in"
"""Hindi"""

hu_hu = "hu-hu"
"""Hungarian"""

id_id = "id-id"
"""Indonesian"""

it_it = "it-it"
"""Italian"""

ja_jp = "ja-jp"
"""Japanese"""

ko_kr = "ko-kr"
"""Korean"""

ms_my = "ms-my"
"""Malay"""

nb_no = "nb-no"
"""Norwegian"""

pl_pl = "pl-pl"
"""Polish"""

pt_br = "pt-br"
"""Portuguese (Brazil)"""

pt_pt = "pt-pt"
"""Portuguese (Portugal)"""

ro_ro = "ro-ro"
"""Romanian"""

ru_ru = "ru-ru"
"""Russian"""

sk_sk = "sk-sk"
"""Slovak"""

sl_si = "sl-si"
"""Slovenian"""

es_mx = "es-mx"
"""Spanish (Mexico)"""

es_es = "es-es"
"""Spanish (Spain)"""

sv_se = "sv-se"
"""Swedish"""

ta_in = "ta-in"
"""Tamil"""

th_th = "th-th"
"""Thai"""

tr_tr = "tr-tr"
"""Turkish"""

vi_vn = "vi-vn"
"""Vietnamese"""
